==> libktorrent_1.0.5.orig.tar.bz2: libktorrent-1.0.5-3/src/datachecker/singledatachecker.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Joris Guisson                                   *
 *   joris.guisson@gmail.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
 ***************************************************************************/
#ifndef BTSINGLEDATACHECKER_H
#define BTSINGLEDATACHECKER_H

#include "datachecker.h"

namespace bt
{

	/**
	 * @author Joris Guisson
	 * 
	 * Data checker for single file torrents.
	 */
	class KTORRENT_EXPORT SingleDataChecker : public DataChecker
	{
	public:
		SingleDataChecker();
		virtual ~SingleDataChecker();

		virtual void check(const QString& path, const Torrent& tor,const QString & dnddir,const BitSet & status);
	};

}

#endif

==> libktorrent_1.1.1.orig.tar.bz2: libktorrent-1.1.1/src/datachecker/singledatachecker.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Joris Guisson                                   *
 *   joris.guisson@gmail.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
 ***************************************************************************/
#ifndef BTSINGLEDATACHECKER_H
#define BTSINGLEDATACHECKER_H

#include "datachecker.h"

namespace bt
{

	/**
	 * @author Joris Guisson
	 * 
	 * Data checker for single file torrents.
	 */
	class KTORRENT_EXPORT SingleDataChecker : public DataChecker
	{
	public:
		SingleDataChecker();
		virtual ~SingleDataChecker();

		virtual void check(const QString& path, const Torrent& tor,const QString & dnddir,const BitSet & current_status);
	};

}

#endif
